/*
 * SPDX-FileCopyrightText: Copyright (c) 2003-2022 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the Software),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED AS IS, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef __ls10_dev_nv_xal_ep_h__
#define __ls10_dev_nv_xal_ep_h__
/* This file is autogenerated.  Do not edit */
#define NV_XAL_EP                               0x00000FFF:0x00000000 /* RW--D */
#define NV_XAL_EP_CG                                                                  0x00000A00   /* RW-4R */
#define NV_XAL_EP_CG_IDLE_CG_DLY_CNT                                                         5:0   /* RWIVF */
#define NV_XAL_EP_CG_IDLE_CG_DLY_CNT_HWINIT                                           0x00000000   /* RWI-V */
#define NV_XAL_EP_CG_IDLE_CG_DLY_CNT__PROD                                            0x00000002   /* ----V */
#define NV_XAL_EP_CG_IDLE_CG_EN                                                              6:6   /* RWIVF */
#define NV_XAL_EP_CG_IDLE_CG_EN_ENABLED                                               0x00000001   /* RW--V */
#define NV_XAL_EP_CG_IDLE_CG_EN_DISABLED                                              0x00000000   /* RWI-V */
#define NV_XAL_EP_CG_IDLE_CG_EN__PROD                                                 0x00000001   /* ----V */
#define NV_XAL_EP_CG_STATE_CG_EN                                                             7:7   /*       */
#define NV_XAL_EP_CG_STATE_CG_EN_ENABLED                                              0x00000001   /*       */
#define NV_XAL_EP_CG_STATE_CG_EN_DISABLED                                             0x00000000   /*       */
#define NV_XAL_EP_CG_STATE_CG_EN__PROD                                                0x00000001   /*       */
#define NV_XAL_EP_CG_STALL_CG_DLY_CNT                                                       13:8   /*       */
#define NV_XAL_EP_CG_STALL_CG_DLY_CNT_HWINIT                                          0x00000000   /*       */
#define NV_XAL_EP_CG_STALL_CG_DLY_CNT__PROD                                           0x00000000   /*       */
#define NV_XAL_EP_CG_STALL_CG_EN                                                           14:14   /* RWIVF */
#define NV_XAL_EP_CG_STALL_CG_EN_ENABLED                                              0x00000001   /* RW--V */
#define NV_XAL_EP_CG_STALL_CG_EN_DISABLED                                             0x00000000   /* RWI-V */
#define NV_XAL_EP_CG_STALL_CG_EN__PROD                                                0x00000000   /* RW--V */
#define NV_XAL_EP_CG_QUIESCENT_CG_EN                                                       15:15   /*       */
#define NV_XAL_EP_CG_QUIESCENT_CG_EN_ENABLED                                          0x00000001   /*       */
#define NV_XAL_EP_CG_QUIESCENT_CG_EN_DISABLED                                         0x00000000   /*       */
#define NV_XAL_EP_CG_QUIESCENT_CG_EN__PROD                                            0x00000000   /*       */
#define NV_XAL_EP_CG_WAKEUP_DLY_CNT                                                        19:16   /* RWIVF */
#define NV_XAL_EP_CG_WAKEUP_DLY_CNT_HWINIT                                            0x00000000   /* RWI-V */
#define NV_XAL_EP_CG_WAKEUP_DLY_CNT__PROD                                             0x00000000   /* RW--V */
#define NV_XAL_EP_CG_THROT_CLK_CNT                                                         23:20   /*       */
#define NV_XAL_EP_CG_THROT_CLK_CNT_FULLSPEED                                          0x0000000f   /*       */
#define NV_XAL_EP_CG_THROT_CLK_CNT__PROD                                              0x00000000   /*       */
#define NV_XAL_EP_CG_DI_DT_SKEW_VAL                                                        27:24   /*       */
#define NV_XAL_EP_CG_DI_DT_SKEW_VAL_HWINIT                                            0x00000000   /*       */
#define NV_XAL_EP_CG_DI_DT_SKEW_VAL__PROD                                             0x00000000   /*       */
#define NV_XAL_EP_CG_THROT_CLK_EN                                                          28:28   /*       */
#define NV_XAL_EP_CG_THROT_CLK_EN_ENABLED                                             0x00000001   /*       */
#define NV_XAL_EP_CG_THROT_CLK_EN_DISABLED                                            0x00000000   /*       */
#define NV_XAL_EP_CG_THROT_CLK_EN__PROD                                               0x00000000   /*       */
#define NV_XAL_EP_CG_THROT_CLK_SW_OVER                                                     29:29   /*       */
#define NV_XAL_EP_CG_THROT_CLK_SW_OVER_EN                                             0x00000001   /*       */
#define NV_XAL_EP_CG_THROT_CLK_SW_OVER_DIS                                            0x00000000   /*       */
#define NV_XAL_EP_CG_THROT_CLK_SW_OVER__PROD                                          0x00000000   /*       */
#define NV_XAL_EP_CG_PAUSE_CG_EN                                                           30:30   /*       */
#define NV_XAL_EP_CG_PAUSE_CG_EN_ENABLED                                              0x00000001   /*       */
#define NV_XAL_EP_CG_PAUSE_CG_EN_DISABLED                                             0x00000000   /*       */
#define NV_XAL_EP_CG_PAUSE_CG_EN__PROD                                                0x00000000   /*       */
#define NV_XAL_EP_CG_HALT_CG_EN                                                            31:31   /*       */
#define NV_XAL_EP_CG_HALT_CG_EN_ENABLED                                               0x00000001   /*       */
#define NV_XAL_EP_CG_HALT_CG_EN_DISABLED                                              0x00000000   /*       */
#define NV_XAL_EP_CG_HALT_CG_EN__PROD                                                 0x00000000   /*       */
#define NV_XAL_EP_CG1                                                                 0x00000A04   /* RW-4R */
#define NV_XAL_EP_CG1_MONITOR_CG_EN                                                          0:0   /* RWIVF */
#define NV_XAL_EP_CG1_MONITOR_CG_EN_ENABLED                                           0x00000001   /* RW--V */
#define NV_XAL_EP_CG1_MONITOR_CG_EN_DISABLED                                          0x00000000   /* RWI-V */
#define NV_XAL_EP_CG1_MONITOR_CG_EN__PROD                                             0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG                                                                  24:2   /*       */
#define NV_XAL_EP_CG1_SLCG_ENABLED                                                    0x00000000   /*       */
#define NV_XAL_EP_CG1_SLCG_DISABLED                                                   0x007fffff   /*       */
#define NV_XAL_EP_CG1_SLCG__PROD                                                      0x00000000   /*       */
#define NV_XAL_EP_CG1_SLCG_DOWNARB                                                           2:2   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_DOWNARB_ENABLED                                            0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_DOWNARB_DISABLED                                           0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_DOWNARB__PROD                                              0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_UPARB                                                             3:3   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_UPARB_ENABLED                                              0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_UPARB_DISABLED                                             0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_UPARB__PROD                                                0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_PRIREQ                                                            4:4   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_PRIREQ_ENABLED                                             0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_PRIREQ_DISABLED                                            0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_PRIREQ__PROD                                               0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_PRIRSP                                                            5:5   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_PRIRSP_ENABLED                                             0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_PRIRSP_DISABLED                                            0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_PRIRSP__PROD                                               0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_JOIN                                                              6:6   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_JOIN_ENABLED                                               0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_JOIN_DISABLED                                              0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_JOIN__PROD                                                 0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_JTAG                                                              7:7   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_JTAG_ENABLED                                               0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_JTAG_DISABLED                                              0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_JTAG__PROD                                                 0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_PM                                                                9:9   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_PM_ENABLED                                                 0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_PM_DISABLED                                                0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_PM__PROD                                                   0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_UNROLL_MEM                                                      10:10   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_UNROLL_MEM_ENABLED                                         0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_UNROLL_MEM_DISABLED                                        0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_UNROLL_MEM__PROD                                           0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_MEMOP                                                           11:11   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_MEMOP_ENABLED                                              0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_MEMOP_DISABLED                                             0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_MEMOP__PROD                                                0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_MEMRSP                                                          12:12   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_MEMRSP_ENABLED                                             0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_MEMRSP_DISABLED                                            0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_MEMRSP__PROD                                               0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_MSIX                                                            13:13   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_MSIX_ENABLED                                               0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_MSIX_DISABLED                                              0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_MSIX__PROD                                                 0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_RXMAP                                                           14:14   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_RXMAP_ENABLED                                              0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_RXMAP_DISABLED                                             0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_RXMAP__PROD                                                0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_FBI_UP                                                          15:15   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_FBI_UP_ENABLED                                             0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_FBI_UP_DISABLED                                            0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_FBI_UP__PROD                                               0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_TXMAP                                                           16:16   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_TXMAP_ENABLED                                              0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_TXMAP_DISABLED                                             0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_TXMAP__PROD                                                0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_PRI_TRACKER                                                     21:21   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_PRI_TRACKER_ENABLED                                        0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_PRI_TRACKER_DISABLED                                       0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_PRI_TRACKER__PROD                                          0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_FASTFLUSH                                                       23:23   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_FASTFLUSH_ENABLED                                          0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_FASTFLUSH_DISABLED                                         0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_FASTFLUSH__PROD                                            0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_DFD                                                             24:24   /* RWIVF */
#define NV_XAL_EP_CG1_SLCG_DFD_ENABLED                                                0x00000000   /* RW--V */
#define NV_XAL_EP_CG1_SLCG_DFD_DISABLED                                               0x00000001   /* RWI-V */
#define NV_XAL_EP_CG1_SLCG_DFD__PROD                                                  0x00000000   /* RW--V */
#endif // __ls10_dev_nv_xal_ep_h__
